pub fn load(path: &Path) -> Result<Vec<CheckpointEntry>>Expand description
Load every entry from a checkpoint file. Non-existent files return an empty vec (first run). Malformed lines are skipped with a warning to stderr.
pub fn load(path: &Path) -> Result<Vec<CheckpointEntry>>Load every entry from a checkpoint file. Non-existent files return an empty vec (first run). Malformed lines are skipped with a warning to stderr.